@@ -27,7 +27,8 @@ import Utils
 
 keywords = [ "have", "show", "obtain", "where", "proof"
            , "ultimately", "finally", "assume", "let", "then"
-           , "moreover", "also", "from", "defines", "fixes"]
+           , "moreover", "also", "from", "defines", "fixes"
+           , "note"]
 
 -- | parses and returns any text between start and end.
 textBetween :: String -> String -> Parser String
@@ -90,35 +91,55 @@ innerText :: Parser String
 innerText = ("\"" `textBetween` "\"") <|> string "?thesis"
 
 -- | parses a preamble of definition, smth. like 
--- "IsATopology ("_ {is a topology}" [90] 91) where"
-
-defpreamble :: Parser (String, String)
+-- IsATopology ("_ {is a topology}" [90] 91) where 
+-- or
+-- IsASet :: "i\<Rightarrow>o" ("_ isASet" [90] 90) where
+defpreamble :: Parser (String, String, String)
 defpreamble = do
    name <- itemName
    spaces
+   ts <- option "" typespec
+   spaces 
    spec <- textBetween "(" ")"
    spaces
    string "where"
-   return (name, spec) 
+   return (name, ts,spec) 
 
+-- | parses a type specification like 
+-- :: "i\<Rightarrow>o") 
+-- This is very rarely needed as Isabelle does type inference.
+typespec :: Parser String
+typespec = do
+ string ":: "
+ s <- textBetween "\"" "\""
+ return s
 
--- | parses definitions. Isabelle 2007 uses the keyword "definition"
+-- | parses an assertion label with a possible "simp" modifier. 
+-- The parser returns a string which is the label and True if the simp was present or False if not
+labelsimp :: Parser (String, Bool)
+labelsimp = do 
+   dn <- varname
+   spaces
+   s <- option "" (string "[simp]")
+   char ':'
+   return (dn, s /= "")
+
+-- | parses definitions. Note we require a space before \<equiv> in the definition
 definition :: Parser FormalItem
 definition = do
    string "definition"
    spaces
-   (name,spec) <- option ("","") defpreamble
-   spaces 
+   (name,tspec,spec) <- option ("","","") defpreamble
+   spaces
+   ls <- option ("", False) labelsimp
+   spaces   
    d <- innerText
    return Definition
-      { defname = if (name /= "") then name else takeWhile (/= '(') d
-      , defspec = spec
-      , def = d } 
-
--- | parses formal items
-{-parseFormalItem :: Parse FormalItem
-parseFormalItem = do
-   fi <- ( --}
+      { defname = if (name /= "") then name else extrName d
+      , deftypespec = spec
+      , deflabel = ls
+      , def = d }
+   where extrName = takeWhile (/= '(') . takeWhile (/= ' ')
 
 -- | parses locale 
 locale :: Parser FormalItem
@@ -167,12 +188,10 @@ locItemDefines :: Parser LocaleItem
 locItemDefines = do
    string "defines"
    spaces
-   dn <- varname
-   spaces
-   string "[simp]:"
+   ls <- labelsimp
    spaces
    ld <- "\"" `textBetween` "\""
-   return ( Defines { definedName = dn, locdef = ld } )
+   return ( Defines { locdefNameSimp = ls, locdef = ld } )
 
 -- | parses an "assumes" locale item
 locItemAssumes :: Parser LocaleItem
