@@ -33,24 +33,56 @@ inner2LatexSym = [("\\<longrightarrow>", "\\longrightarrow ")
                  ,(" O ", "\\circ ")
                  ,("\\<and>", "\\wedge ")
                  ,("\\<approx>", "\\approx ")
+                 ,("\\<bullet>", "\\bullet ")
+                 ,("\\<ca>", " + ")
+                 ,("\\<caddset>", " + ")
+                 ,("\\<cmulset>", "\\cdot ")
+                 ,("\\<circ>", "\\circ ")
+                 ,("\\<cdiv>", " / ")
+                 ,("\\<cltrrset>", "< ")
+                 ,("\\<cn>", " - ")
+                 ,("\\<cmnf>", "-\\infty ")
+                 ,("\\<complex>", "\\mathbb{C} ")
+                 ,("\\<cpnf>", "+\\infty ") 
+                 ,("\\<cs>", " - ")
+                 ,("\\<delta>", "\\delta ")
+                 ,("\\<epsilon>","\\varepsilon ") 
+                 ,("\\<fp>", " + ")
+                 ,("\\<fm>", " - ")
+                 ,("\\<gamma>", "\\gamma ")
+                 ,("\\<Gamma>", "\\Gamma ")
+                 ,("\\<i>", "\\imath ")
+                 ,("max\\<delta>", "\\text{ max}\\delta " )
+                 ,("\\<mulset>", "\\cdot ")
+                 ,("\\<nat>", "\\mathbb{N} ")
                  ,("\\<subseteq>", "\\subseteq ")
                  ,("\\<times>", "\\times ") 
                  ,("\\<rightarrow>", "\\rightarrow ")
                  ,("\\<langle>", "\\langle ")
                  ,("\\<Lambda>", "\\Lambda ")
                  ,("\\<lesssim>", "\\preceq ")
+                 ,("\\<lsr>", "<_{\\mathbb{R}} ")
+                 ,("\\<lsrset>", "<_{\\mathbb{R}} ")
                  ,("\\<rangle>", "\\rangle ")
                  ,("\\<cdot>", "\\cdot ")
+                 ,("\\<degree>", "^\\circ ")
                  ,("\\<dots>", "\\ldots ")
                  ,("\\<equiv>", "\\equiv ")
                  ,("\\<hookleftarrow>", "\\hookleftarrow ")
+                 ,("Infim", "\\text{ Infim}")
+                 ,("\\<int>", "\\mathbb{Z} ")
+                 ,("\\<real>", "\\mathbb{R} ")
                  ,("\\<inter>", "\\cap ")
                  ,("\\<Inter>", "\\bigcap ")
-                 ,("\\<le>", "\\leq")
+                 ,("\\<le>", "\\leq ")
+                 ,("\\<lfloor>", "\\lfloor ")
+                 ,("\\<ls>", " < ")
+                 ,("\\<lsq>", "\\leq ")
                  ,("\\<longleftrightarrow>", "\\longleftrightarrow ")
                  ,("\\<A>", "\\mathcal{A} ")
                  ,("\\<zero>", "0 ")
                  ,("\\<M>", "\\mathcal{M} ")
+                 ,("\\<S>", "\\mathcal{S} ")
                  ,("\\<ra>", " + ")
                  ,("\\<rm>", " - ")
                  ,("\\<not>","\\neg ")
@@ -59,17 +91,32 @@ inner2LatexSym = [("\\<longrightarrow>", "\\longrightarrow ")
                  ,("\\<one>", "1 ")
                  ,("\\<oplus>","\\oplus ")
                  ,("\\<or>", "\\vee ")
+                 ,("Orders", "\\text{ orders }") 
                  ,("\\<partial>", "\\partial ")
                  ,("\\<phi>", "\\phi ")
                  ,("\\<pr>", "\\prod ")
+                 ,("\\<psi>", "\\psi ")
                  ,("\\<Prod>", "\\prod ")
                  ,("\\<ra>", " + ")
+                 ,("\\<rfloor>", "\\rfloor ")
                  ,("\\<rs>", " - ")
                  ,("\\<rm>", " - ")
+                 ,("\\<rmu>", "\\cdot ")
                  ,("\\<sigma>", "\\sigma ")
+                 ,("\\<sim>", "\\sim ")
+                 ,("\\<sm>", "-") 
                  ,("\\<squnion>", "\\sqcup ")
+                 ,("Sup", "\\text{ Sup}")
                  ,("\\<tau>", "\\tau ")
+                 ,("\\<three>", " 3 ") 
                  ,("\\<two>", " 2 ")
+                 ,("\\<four>", " 4 ")
+                 ,("\\<five>", " 5 ")
+                 ,("\\<six>", " 6 ")
+                 ,("\\<seven>", " 7 ")
+                 ,("\\<eight>", " 8 ")
+                 ,("\\<nine>", " 9 ")
+                 ,("\\<zero>", " 0 ")
                  ,("\\<twosuperior>","^2 ")
                  ,("\\<union>", "\\cup ")
                  ,("\\<Union>", "\\bigcup ")
@@ -80,10 +127,23 @@ inner2LatexSym = [("\\<longrightarrow>", "\\longrightarrow ")
                  ,("#", "\\ \\sharp ")
                  ,("IsAgroup","\\text{IsAgroup}")
                  ,("IsAmonoid","\\text{IsAmonoid}")
+                 ,("isASet","\\text{ is a set }")
                  ,("THE", "\\text{The }")
+                 ,("Xor", "\\text{ Xor } ")
+                 ,(" zdiv ", "\\text{ zdiv }")
+                 ,(" zmod ", "\\text{ zmod }")
+                 ,("\\<zmu>", "\\cdot ")
+                 ,("\\<za>", " + ")
+                 ,("\\<zlq>", "\\leq ")
+                 ,("\\<zm>", " - ")
+                 ,("\\<zs>", " - ")
                  ,("\\<^isub>", "_")
+                 ,("\\<^isup>", "^")
+                 ,("\\<^sub>", "_")
+                 ,("\\<^sup>", "^")
                  ,("_", "\\_") 
                  ,("-``", "^{-1}")
+                 ,("$", "\\ \\$ ")
                  ,("\\<inverse>", "^{-1}")]
  
 
